#!/usr/bin/env bash

mypath="$(dirname "`readlink -f "$0"`")"

install_dir="$(cd "$mypath" && pwd)"

current_version=$(cat "$install_dir"/VERSION)
repo_version=$(curl -s http://repo.pti-cosmetics.com/odoo/whcheckout.VERSION)

echo "Current version is $current_version"
echo "Repo version is $repo_version"

if [[ "$repo_version" < "$current_version" ]]; then
	echo "Not Upgrading"
	exit 1
fi

if [[ "repo_version" == "$current_version" ]]; then
	echo "Reinstalling"
fi

download_url="http://repo.pti-cosmetics.com/odoo/whcheckout-$repo_version-nojre.tar.gz"
echo "Downloading $download_url"
tmpfile=$(mktemp)
curl -o $tmpfile $download_url
res=$?
if [[ $res -ne 0 ]]; then
	echo "CURL returned $res, aborting upgrade"
	exit 2
fi

cd $install_dir
cd ..
echo "Extracting application data"
tar -xzf $tmpfile
res=$?
if [[ $res -ne 0 ]]; then
	echo "TAR returned $res, aborting upgrade"
	exit 3
fi

rm $tmpfile

echo "Upgrade finished. Current is now $(cat "$install_dir"/VERSION)"

